==> nextcloud-15.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/support/l10n/cs.js <==
OC.L10N.register(
    "support",
    {
    "Link:" : "Odkaz:",
    "Password:" : "Heslo:",
    "Generating system report failed." : "Vytvoření výkazu o systému se nezdařilo.",
    "Subscription notifications" : "Oznámení o předplatném",
    "Could not create folder \"System information\" to store generated report." : "Nepodařilo se vytvořit složku „System information“, potřebnou pro uložení vytvořeného výkazu.",
    "Could not create file \"%s\" to store generated report." : "Nepodařilo se vytvořit soubor „%s“, potřebný pro zapsání vytvořeného výkazu.",
    "Could not share file \"%s\"." : "Soubor „%s“ nelze sdílet.",
    "Nextcloud Subscription" : "Předplatné Nextcloud",
    "Your server has no Nextcloud Subscription or your Subscription has expired." : "Váš server nemá Nextcloud předplatné nebo to skončilo.",
    "Your Nextcloud server subscription does not cover your number of users." : "Vaše předplatné Nextcloud serveru nepokrývá váš počet uživatelů.",
    "Your Nextcloud Subscription has expired!" : "Vaše Nextcloud předplatné skončilo!",
    "Your server has no Nextcloud Subscription" : "Váš server nemá žádné Nextcloud předplatné",
    "Your Nextcloud server is not backed by a Nextcloud Enterprise Subscription." : "Váš Nextcloud server není zajišťován předplatným Nextcloud Enterprise.",
    "A Nextcloud Support Subscription means the original developers behind your private cloud server are 100% dedicated to your success: the security, scalability, performance and functionality of your service!" : "Předplatné podpory Nextcloud znamená, že původní vývojáři stojí za vaším soukromém cloudovým serverem jsou 100% oddáni vašemu úspěchu: zabezpečení, škálovatelnosti, výkonu a funkci vaší služby!",
    "If you encounter a problem and your server does no longer work, blocking employees from sharing or customers from downloading and uploading files, you don't have to rely on searching online and asking volunteers on forums and social media for a solution. You have direct access to our experienced engineers who help you track down and fix the problem." : "Pokud narazíte na problém a váš server přestane fungovat, což zaměstnancům znemožňuje sdílet nebo zákazníkům stahovat a nahrávat soubory, nemusíte být závislí na hledání na Internetu a dotazování se dobrovolníků na diskuzních fórech a sociálních médiích na řešení. Máte přímý přístup k našim zkušeným inženýrům kteří vám pomohou dohledat a opravit problém.",
    "You have a contract with the vendor providing confidential security information, mitigations, patches and updates." : "Máte smlouvu s výrobcem poskytující důvěrné informace o zabezpečení, snížení rizika, opravy a aktualizace.",
    "If you want to skip a release or two and stay a bit longer on your current version without disruptions, you don't have to run software without security updates. We deliver them to you as long as is needed!" : "Pokud chcete přeskočit jedno-dvě vydání a zůstat o trochu déle vaší stávající verzi bez vyrušování, nemusíte provozovat software bez oprav zabezpečení. Budeme vám je dodávat jak dlouho bude třeba!",
    "If you have performance and scalability issues you have the best expertise at hand, instead of having to search on the web and hope you find a solution." : "Pokud máte problémy s výkonem a škálováním, máte k dispozici nejlepší expertízu, namísto hledání na webu a doufání v nalezení řešení.",
    "If you are asked how the compliance of Nextcloud is and if you can deliver a data export under GDPR, HIPAA or other rules, you have access to the right documentation and can tap into our expertise to respond quickly and accurately." : "Pokud budete dotázání na to, jak Nextcloud odpovídá legislativě GDPR, HIPAA a dalším pravidlům a zda můžete poskytnou export dat, které jim odpovídají, máte přístup ke správné dokumentaci a můžete se na nás obrátit, abyste mohli odpovědět rychle a přesně.",
    "We can also provide you Outlook integration, Online Office, scalable integrated audio-video and chat communication an other features only available in a very limited form for free. And we can develop further integrations and capabilities you need." : "Dovedeme vám také poskytnout napojení na Outlook, Online Office, škálovatelnou vestavěnou audio-video a chat komunikaci a další funkce, které jsou ve variantě zdarma velmi omezené. A můžeme pro vás vyvinout další napojení a funkce.",
    "A subscription helps you get the most out of Nextcloud! Don't your users deserve the best?" : "Předplatné pomůže získat z Nextcloud nejvíc! Nezaslouží si vaši uživatelé to nejlepší?",
    "Learn more now" : "Dozvědět se víc",
    "This mail was sent to all administrators by the support app on your Nextcloud instance at %1$s because you have over %2$s registered users." : "Tento email byl poslán všem správcům podpůrnou aplikací na vaší instanci Nextcloud na %1$s, protože máte přes %2$s registrovaných uživatelů.",
    "Your Nextcloud server Subscription is over limit" : "Vaše předplatné Nextcloud serveru překračuje limit",
    "Dear admin," : "Vážený správče,",
    "Your Nextcloud Subscription doesn't cover the number of users who are currently active on this server. Please contact you Nextcloud account manager to get your subscription updated!" : "Vaše Nextcloud předplatné nepokrývá počet uživatelů, kteří jsou nyní aktivní na tomto serveru. Obraťte se na svého obchodníka v Nextcloud pro rozšíření předplatného!",
    "%1$s is your account manager and can be reached by email via %2$s or by phone via %3$s." : "%1$s je váš správce účtu je možné se na něj obrátit prostřednictvím emailu %2$s nebo telefonu %3$s.",
    "Thank you," : "Děkujeme,",
    "Your Nextcloud team" : "Tým Nextcloud",
    "This mail was sent to all administrators by the support app on your Nextcloud instance at %s because you have more users than what your subscription covers." : "Tento email byl poslán všem správcům podpůrnou aplikací na vaší instanci Nextcloud na %s, protože máte více uživatelů než pokrývá vaše předplatné.",
    "Your Nextcloud server Subscription is expired" : "Vaše předplatné Nextcloud serveru skončilo",
    "Your Nextcloud server Subscription is expired!" : "Vaše předplatné Nextcloud serveru skončilo!",
    "Your Nextcloud Subscription has expired! Please contact you Nextcloud account manager to get your subscription updated!" : "Platnost vašeho Nextcloud předplatného skončila! Obraťte se na obchodníka Nextcloud pro aktualizaci předplatného!",
    "This mail was sent to all administrators by the support app on your Nextcloud instance at %s because your subscription expired." : "Tento email byl poslán všem správcům podpůrnou aplikací na vaší instanci Nextcloud na %s, protože platnost vašeho předplatného skončila.",
    "Support" : "Podpora",
    "Getting support and help for your Nextcloud" : "Získání podpory a nápovědy pro váš Nextcloud",
    "The support app covers you with direct access to help and consulting resources, dedicated contact options to your account manager and an overview of your enterprise subscription." : "Aplikace podpora vás kryje přímým přístupem ke zdrojům pomoci a konzultace, vyhrazenými kontaktními možnostmi na vašeho obchodníka a přehled vašeho podnikového předplatného.",
    "Basic subscription" : "Základní předplatné",
    "Standard subscription" : "Standardní předplatné",
    "Premium subscription" : "Prémiové předplatné",
    "Géant subscription" : "Géant předplatné",
    "Silver partner subscription" : "Předplatné stříbrného partnera",
    "Gold partner subscription" : "Předplatné zlatého partnera",
    "Subscription" : "Předplatné",
    "Over subscription limit" : "Přes limit předplatného",
    "Valid subscription" : "Platné předplatné",
    "Expired subscription" : "Platnost předplatného skončila",
    "Subscription key:" : "Klíč předplatného:",
    "_Expires in %n year_::_Expires in %n years_" : ["Platnost skončí za %n rok","Platnost skončí za %n roky","Platnost skončí za %n let","Platnost skončí za %n roky"],
    "_Expires in %n month_::_Expires in %n months_" : ["Platnost skončí za %n měsíc","Platnost skončí za %n měsíce","Platnost skončí za %n měsíců","Platnost skončí za %n měsíce"],
    "_Expires in %n week_::_Expires in %n weeks_" : ["Platnost skončí za %n týden","Platnost skončí za %n týdny","Platnost skončí za %n týdnů","Platnost skončí za %n týdny"],
    "_Expires in %n day_::_Expires in %n days_" : ["Platnost končí za %n den","Platnost končí za %n dny","Platnost končí za %n dnů","Platnost končí za %n dny"],
    "_For %n users_::_For %n users_" : ["Pro %n uživatele","Pro %n uživatele","Pro %n uživatelů","Pro %n uživatele"],
    "_currently at %n user_::_currently at %n users_" : ["nyní na %n uživateli","nyní na %n uživatelích","nyní na %n uživatelích","nyní na %n uživatelích"],
    "Includes support for %s" : "Obsahuje podporu pro %s",
    "Includes support for %1$s & %2$s" : "Zahrnuje podporu pro %1$s a %2$s",
    "Includes support for %1$s, %2$s & %3$s" : "Zahrnuje podporu pro %1$s, %2$s a %3$s",
    "Update subscription key" : "Aktualizovat klíč předplatného",
    "%s is your account manager. Don't hesitate to reach out to us if you have questions regarding your subscription." : "%s je váš obchodník. Neváhejte se na něho obrátit pokud máte nějaké dotazy ohledně předplatného.",
    "You can find answers to common question in our portal and also file support requests there." : "Odpovědi na běžné dotazy naleznete na našem portálu, kde je také možné vytvářet požadavky na podporu.",
    "Access Nextcloud portal" : "Přístup k Nextcloud portálu",
    "System information" : "Informace o systému",
    "Collect system information for support cases. The button below generates a text file in the folder \"System information\" and shares it as password protected public link. The link is valid for 2 weeks." : "Shromáždit informace o systému pro technickou podporu. Tlačítko níže vytvoří textový soubor ve složce „System information“ (Informace o systému) a nasdílí ho formou veřejného odkazu, chráněného heslem. Odkaz je platný po dobu dvou týdnů.",
    "Generate system report" : "Vytvořit výkaz o systému",
    "Enterprise subscription recommended" : "Doporučeno předplatné pro podniky",
    "No active enterprise subscription" : "Žádné aktivní předplatné pro podniky",
    "Unsupported" : "Nepodporováno",
    "This Nextcloud server has no Enterprise Subscription." : "Tento Nextcloud server nemá žádné předplatné pro podniky",
    "A Nextcloud Enterprise Subscription helps you get the most out of your Nextcloud, keep your data secure and your server working reliably at all times." : "Předplatné Nextcloud pro podniky pomůže získat z Nextcloud nejvíce, uchovat data zabezpečená a váš server vždy spolehlivě fungující.",
    "Advantages" : "Výhody",
    "Access to the technical expertise of the Nextcloud developers through documentation and support" : "Přístup k technické expertíze vývojářů Nextcloud prostřednictvím dokumentace a podpory",
    "Access to additional capabilities like Outlook integration, online office and more" : "Přístup k dalším možnostem, jako napojení na Outlook, online office a další",
    "Access to scalability expertise and scalability capabilities for Files and Talk" : "Přístup k expertýze a schopnostem škálování pro Soubory a Komunikaci",
    "Optional branding, consulting, architecture advice" : "Volitelné opatření firemním vzhledem, konzultace a poradenství ohledně architektury",
    "Confidential security notification service, mitigations, patches and advice" : "Služba důvěrného upozorňování na chyby zabezpečení, snížení rizika jejich zneužití, opravy a doporučení",
    "Compliance certification, advice and documentation" : "Certifikace shody, doporučení a dokumentace",
    "Get a quote" : "Zažádat o nabídku",
    "More information" : "Více informací",
    "Subscription benefits" : "Výhody předplatného",
    "Pricing" : "Ceny",
    "Commmunity support" : "Komunitní podpora",
    "Forum" : "Diskuzní fórum",
    "Nextcloud is free software which is supported by a very active community. Please register at the forum to ask questions and discuss with others." : "Nextcloud je svobodný software, který je podporován velmi aktivní komunitou. Zaregistrujte se na diskuzním fóru a ptejte se zde a diskutujte s ostatními.",
    "GitHub" : "GitHub",
    "Nextcloud uses GitHub as platform to collaboratively work. You can file bug reports directly there." : "Vývojáři Nextcloud používají jako platformu pro spolupráci Github. Hlášení chyb je možné vyplnit přímo tam.",
    "Chat" : "Chat",
    "Chat with us on our IRC channel #nextcloud on Freenode." : "Chatujte s námi na našem IRC kanálu #nextcloud na Freenode.",
    "Nextcloud forum" : "Diskuzní fórum o Nextcloud",
    "Nextcloud at GitHub" : "Nextcloud na GitHub",
    "Open chat" : "Otevřít chat",
    "Subscription key" : "Klíč předplatného",
    "If you have an active Nextcloud Subscription please enter your subscription key here." : "Pokud máte aktivní Nextcloud předplatné, zadejte jeho klíč sem.",
    "Learn more about an enterprise subscription." : "Zjistit víc o předplatném pro podniky.",
    "Set subscription key" : "Nastavit klíč předplatného",
    "The subscription info could not properly fetched right now. A retry is scheduled. Please check back later." : "V tuto chvíli se nedaří správně získat informace o předplatném. Je naplánován opětovný pokus. Podívejte se sem později.",
    "The subscription key was invalid." : "Klíč předplatného není platný.",
    "The subscription key could not be verified, because this server has no internet connection. Please reach out to the support team to get this resolved." : "Klíč předplatného není možné ověřit, protože tento server nemá připojení k Internetu. Pro řešení se obraťte na technickou podporu.",
    "The subscription key had an invalid format." : "Klíč předplatného nemá platný formát.",
    "While fetching the subscription information an error happened." : "Při získávání informací o předplatném došlo k chybě.",
    "News" : "Novinky",
    "To get up to date information what is going on at Nextcloud sign up for the newsletter and follow us on our social media accounts." : "Pro získání aktuálních informací ohledně dění v Nextcloud se přihlaste k odběru novinek a následujte nás na sociálních sítích.",
    "Follow us on Google+" : "Následujte nás na Google+",
    "Like our Facebook page" : "Lajkujte naši Facebookovou stránku",
    "Follow us on Twitter" : "Následujte nás na Twitteru",
    "Check out our blog" : "Čtete náš blog",
    "Subscribe to our newsletter" : "Přihlaste se k odběru našeho zpravodaje"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");

==> nextcloud-15.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/support/l10n/cs.js <==
OC.L10N.register(
    "support",
    {
    "Link:" : "Odkaz:",
    "Password:" : "Heslo:",
    "Generating system report failed." : "Vytvoření výkazu o systému se nezdařilo.",
    "Subscription notifications" : "Oznámení o předplatném",
    "Could not create folder \"System information\" to store generated report." : "Nepodařilo se vytvořit složku „System information“, potřebnou pro uložení vytvořeného výkazu.",
    "Could not create file \"%s\" to store generated report." : "Nepodařilo se vytvořit soubor „%s“, potřebný pro zapsání vytvořeného výkazu.",
    "Could not share file \"%s\"." : "Soubor „%s“ nelze sdílet.",
    "Nextcloud Subscription" : "Předplatné Nextcloud",
    "Your server has no Nextcloud Subscription or your Subscription has expired." : "Váš server nemá Nextcloud předplatné nebo to skončilo.",
    "Your Nextcloud server subscription does not cover your number of users." : "Vaše předplatné Nextcloud serveru nepokrývá váš počet uživatelů.",
    "Your Nextcloud Subscription has expired!" : "Vaše Nextcloud předplatné skončilo!",
    "Your server has no Nextcloud Subscription" : "Váš server nemá žádné Nextcloud předplatné",
    "Your Nextcloud server is not backed by a Nextcloud Enterprise Subscription." : "Váš Nextcloud server není zajišťován předplatným Nextcloud Enterprise.",
    "A Nextcloud Enterprise Subscription means the original developers behind your self-hosted cloud server are 100% dedicated to your success: the security, scalability, performance and functionality of your service!" : "Předplatné podpory Nextcloud pro podniky znamená, že původní vývojáři stojí za vaším vámi hostovaným cloudovým serverem jsou 100% oddáni vašemu úspěchu: zabezpečení, škálovatelnosti, výkonu a funkci vaší služby!",
    "If your server setup breaks and employees can't work anymore, you don't have to rely on searching online forums for a solution. You have direct access to our experienced engineers!" : "Pokud váš server přestane fungovat a zaměstnanci proto nemohou pracovat, nemusíte být závislí na hledání na Internetu a dotazování se na diskuzních fórech na řešení. Máte přímý přístup k našim zkušeným inženýrům!",
    "You have a contract with the vendor providing early security information, mitigations, patches and updates." : "Máte smlouvu s výrobcem poskytující ranné informace o zabezpečení, snížení rizika, opravy a aktualizace.",
    "If you need to stay longer on your current version without disruptions, you don't have to run software without security updates." : "Pokud potřebujete zůstat o trochu déle na vaší stávající verzi bez vyrušování, nemusíte provozovat software bez oprav zabezpečení.",
    "You have the best expertise at hand to deal with performance and scalability issues." : "Máte po ruce nejlepší expertízu při potýkání se s problémy s výkonem a škálováním.",
    "You have access to the right documentation and expertise to quickly answer compliance questions or deliver on GDPR, HIPAA and other regulation requirements." : "Máte přístup ke správné dokumentaci a expertíze pro rychlé zodpovězení otázek ohledně splňování legislativy (GDPR, HIPAA a ostatních požadavků).",
    "We can also provide Outlook integration, Online Office, scalable integrated audio-video and chat communication an other features only available in a limited form for free or develop further integrations and capabilities to you needs." : "Dovedeme také poskytnout napojení na Outlook, Online Office, škálovatelnou vestavěnou audio-video a chat komunikaci a další funkce, které jsou ve variantě zdarma velmi omezené. Dále pro vás můžeme vyvinout další napojení a funkce.",
    "A subscription helps you get the most out of Nextcloud!" : "Předplatné pomůže získat z Nextcloud nejvíce!",
    "Learn more now" : "Dozvědět se víc",
    "This mail was sent to all administrators by the support app on your Nextcloud instance at %1$s because you have over %2$s registered users." : "Tento email byl poslán všem správcům podpůrnou aplikací na vaší instanci Nextcloud na %1$s, protože máte přes %2$s registrovaných uživatelů.",
    "Your Nextcloud server Subscription is over limit" : "Vaše předplatné Nextcloud serveru překračuje limit",
    "Dear admin," : "Vážený správče,",
    "Your Nextcloud Subscription doesn't cover the number of users who are currently active on this server. Please contact you Nextcloud account manager to get your subscription updated!" : "Vaše Nextcloud předplatné nepokrývá počet uživatelů, kteří jsou nyní aktivní na tomto serveru. Obraťte se na svého obchodníka v Nextcloud pro rozšíření předplatného!",
    "%1$s is your account manager and can be reached by email via %2$s or by phone via %3$s." : "%1$s je váš správce účtu je možné se na něj obrátit prostřednictvím e-mailu %2$s nebo telefonu %3$s.",
    "Thank you," : "Děkujeme,",
    "Your Nextcloud team" : "Tým Nextcloud",
    "This mail was sent to all administrators by the support app on your Nextcloud instance at %s because you have more users than what your subscription covers." : "Tento email byl poslán všem správcům podpůrnou aplikací na vaší instanci Nextcloud na %s, protože máte více uživatelů než pokrývá vaše předplatné.",
    "Your Nextcloud server Subscription is expired" : "Vaše předplatné Nextcloud serveru skončilo",
    "Your Nextcloud server Subscription is expired!" : "Vaše předplatné Nextcloud serveru skončilo!",
    "Your Nextcloud Subscription has expired! Please contact you Nextcloud account manager to get your subscription updated!" : "Platnost vašeho Nextcloud předplatného skončila! Obraťte se na obchodníka Nextcloud pro aktualizaci předplatného!",
    "This mail was sent to all administrators by the support app on your Nextcloud instance at %s because your subscription expired." : "Tento email byl poslán všem správcům podpůrnou aplikací na vaší instanci Nextcloud na %s, protože platnost vašeho předplatného skončila.",
    "Support" : "Podpora",
    "Getting support and help for your Nextcloud" : "Získání podpory a nápovědy pro váš Nextcloud",
    "The support app covers you with direct access to help and consulting resources, dedicated contact options to your account manager and an overview of your enterprise subscription." : "Aplikace podpora vás kryje přímým přístupem ke zdrojům pomoci a konzultace, vyhrazenými kontaktními možnostmi na vašeho obchodníka a přehled vašeho podnikového předplatného.",
    "Basic subscription" : "Základní předplatné",
    "Standard subscription" : "Standardní předplatné",
    "Premium subscription" : "Prémiové předplatné",
    "Géant subscription" : "Géant předplatné",
    "Silver partner subscription" : "Předplatné stříbrného partnera",
    "Gold partner subscription" : "Předplatné zlatého partnera",
    "Subscription" : "Předplatné",
    "Over subscription limit" : "Přes limit předplatného",
    "Valid subscription" : "Platné předplatné",
    "Expired subscription" : "Platnost předplatného skončila",
    "Subscription key:" : "Klíč předplatného:",
    "_Expires in %n year_::_Expires in %n years_" : ["Platnost skončí za %n rok","Platnost skončí za %n roky","Platnost skončí za %n let","Platnost skončí za %n roky"],
    "_Expires in %n month_::_Expires in %n months_" : ["Platnost skončí za %n měsíc","Platnost skončí za %n měsíce","Platnost skončí za %n měsíců","Platnost skončí za %n měsíce"],
    "_Expires in %n week_::_Expires in %n weeks_" : ["Platnost skončí za %n týden","Platnost skončí za %n týdny","Platnost skončí za %n týdnů","Platnost skončí za %n týdny"],
    "_Expires in %n day_::_Expires in %n days_" : ["Platnost končí za %n den","Platnost končí za %n dny","Platnost končí za %n dnů","Platnost končí za %n dny"],
    "_For %n users_::_For %n users_" : ["Pro %n uživatele","Pro %n uživatele","Pro %n uživatelů","Pro %n uživatele"],
    "_currently at %n user_::_currently at %n users_" : ["nyní na %n uživateli","nyní na %n uživatelích","nyní na %n uživatelích","nyní na %n uživatelích"],
    "Includes support for %s" : "Obsahuje podporu pro %s",
    "Includes support for %1$s & %2$s" : "Zahrnuje podporu pro %1$s a %2$s",
    "Includes support for %1$s, %2$s & %3$s" : "Zahrnuje podporu pro %1$s, %2$s a %3$s",
    "Update subscription key" : "Aktualizovat klíč předplatného",
    "%s is your account manager. Don't hesitate to reach out to us if you have questions regarding your subscription." : "%s je váš obchodník. Neváhejte se na něho obrátit pokud máte nějaké dotazy ohledně předplatného.",
    "You can find answers to common question in our portal and also file support requests there." : "Odpovědi na běžné dotazy naleznete na našem portálu, kde je také možné vytvářet požadavky na podporu.",
    "Access Nextcloud portal" : "Přístup k Nextcloud portálu",
    "System information" : "Informace o systému",
    "Collect system information for support cases. The button below generates a text file in the folder \"System information\" and shares it as password protected public link. The link is valid for 2 weeks." : "Shromáždit informace o systému pro technickou podporu. Tlačítko níže vytvoří textový soubor ve složce „System information“ (Informace o systému) a nasdílí ho formou veřejného odkazu, chráněného heslem. Odkaz je platný po dobu dvou týdnů.",
    "Generate system report" : "Vytvořit výkaz o systému",
    "Enterprise subscription recommended" : "Doporučeno předplatné pro podniky",
    "No active enterprise subscription" : "Žádné aktivní předplatné pro podniky",
    "Unsupported" : "Nepodporováno",
    "This Nextcloud server has no Enterprise Subscription." : "Tento Nextcloud server nemá žádné předplatné pro podniky",
    "A Nextcloud Enterprise Subscription helps you get the most out of your Nextcloud, keep your data secure and your server working reliably at all times." : "Předplatné Nextcloud pro podniky pomůže získat z Nextcloud nejvíce, uchovat data zabezpečená a váš server vždy spolehlivě fungující.",
    "Advantages" : "Výhody",
    "Access to the technical expertise of the Nextcloud developers through documentation and support" : "Přístup k technické expertíze vývojářů Nextcloud prostřednictvím dokumentace a podpory",
    "Access to additional capabilities like Outlook integration, online office and more" : "Přístup k dalším možnostem, jako napojení na Outlook, online office a další",
    "Access to scalability expertise and scalability capabilities for Files and Talk" : "Přístup k expertýze a schopnostem škálování pro Soubory a Komunikaci",
    "Optional branding, consulting, architecture advice" : "Volitelné opatření firemním vzhledem, konzultace a poradenství ohledně architektury",
    "Confidential security notification service, mitigations, patches and advice" : "Služba důvěrného upozorňování na chyby zabezpečení, snížení rizika jejich zneužití, opravy a doporučení",
    "Compliance certification, advice and documentation" : "Certifikace shody, doporučení a dokumentace",
    "Get a quote" : "Zažádat o nabídku",
    "More information" : "Více informací",
    "Subscription benefits" : "Výhody předplatného",
    "Pricing" : "Ceny",
    "Commmunity support" : "Komunitní podpora",
    "Forum" : "Diskuzní fórum",
    "Nextcloud is free software which is supported by a very active community. Please register at the forum to ask questions and discuss with others." : "Nextcloud je svobodný software, který je podporován velmi aktivní komunitou. Zaregistrujte se na diskuzním fóru a ptejte se zde a diskutujte s ostatními.",
    "GitHub" : "GitHub",
    "Nextcloud uses GitHub as platform to collaboratively work. You can file bug reports directly there." : "Vývojáři Nextcloud používají jako platformu pro spolupráci Github. Hlášení chyb je možné vyplnit přímo tam.",
    "Chat" : "Chat",
    "Chat with us on our IRC channel #nextcloud on Freenode." : "Chatujte s námi na našem IRC kanálu #nextcloud na Freenode.",
    "Nextcloud forum" : "Diskuzní fórum o Nextcloud",
    "Nextcloud at GitHub" : "Nextcloud na GitHub",
    "Open chat" : "Otevřít chat",
    "Subscription key" : "Klíč předplatného",
    "If you have an active Nextcloud Subscription please enter your subscription key here." : "Pokud máte aktivní Nextcloud předplatné, zadejte jeho klíč sem.",
    "Learn more about an enterprise subscription." : "Zjistit víc o předplatném pro podniky.",
    "Set subscription key" : "Nastavit klíč předplatného",
    "The subscription info could not properly fetched right now. A retry is scheduled. Please check back later." : "V tuto chvíli se nedaří správně získat informace o předplatném. Je naplánován opětovný pokus. Podívejte se sem později.",
    "The subscription key was invalid." : "Klíč předplatného není platný.",
    "The subscription key could not be verified, because this server has no internet connection. Please reach out to the support team to get this resolved." : "Klíč předplatného není možné ověřit, protože tento server nemá připojení k Internetu. Pro řešení se obraťte na technickou podporu.",
    "The subscription key had an invalid format." : "Klíč předplatného nemá platný formát.",
    "While fetching the subscription information an error happened." : "Při získávání informací o předplatném došlo k chybě.",
    "News" : "Novinky",
    "To get up to date information what is going on at Nextcloud sign up for the newsletter and follow us on our social media accounts." : "Pro získání aktuálních informací ohledně dění v Nextcloud se přihlaste k odběru novinek a následujte nás na sociálních sítích.",
    "Follow us on Google+" : "Následujte nás na Google+",
    "Like our Facebook page" : "Lajkujte naši Facebookovou stránku",
    "Follow us on Twitter" : "Následujte nás na Twitteru",
    "Check out our blog" : "Čtete náš blog",
    "Subscribe to our newsletter" : "Přihlaste se k odběru našeho zpravodaje"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");
